export declare type ProxyPersistStorageEngine = {
    getItem: (name: string) => string | null | Promise<string | null>;
    setItem: (name: string, value: string) => void | Promise<void>;
    removeItem: (name: string) => void | Promise<void>;
    getAllKeys: () => string[] | Promise<string[]>;
};
export declare enum PersistStrategy {
    SingleFile = "SingleFile",
    MultiFile = "MultiFile"
}
declare type Write = () => ReturnType<ProxyPersistStorageEngine['setItem']>;
declare type BulkWrite = () => Promise<ReturnType<Write>[]>;
declare type OnBeforeBulkWrite = (bulkWrite: BulkWrite) => void;
declare type OnBeforeWrite = (write: Write, path: string) => void;
declare type Version = number;
interface IProxyWithPersistInputs<S extends object> {
    name: string;
    version: Version;
    getStorage: () => ProxyPersistStorageEngine | Promise<ProxyPersistStorageEngine>;
    persistStrategies: PersistStrategy | {
        [key: string]: PersistStrategy;
    };
    migrations: Record<Version, (() => Promise<void> | void) | undefined>;
    onBeforeWrite?: OnBeforeWrite;
    onBeforeBulkWrite?: OnBeforeBulkWrite;
    initialState: S;
}
declare type IPersistedState<State extends object> = {
    [Key in keyof State]: State[Key];
} & {
    _persist: {
        version: number;
    } & ({
        status: 'loading';
        loading: true;
        loaded: false;
        error: null;
    } | {
        status: 'loaded';
        loading: false;
        loaded: true;
        error: null;
    } | {
        status: 'error';
        loading: false;
        loaded: false;
        error: Error;
    });
};
export default function proxyWithPersist<S extends object>(inputs: IProxyWithPersistInputs<S>): IPersistedState<S>;
export {};
